.. _patch_command:

Patch Command
=============

Use this command to patch the metadata of a given dataset

.. argparse::
    :module: anemoi.datasets.__main__
    :func: create_parser
    :prog: anemoi-datasets
    :path: patch
